*********************** REPLICATION FILE : READ ME *****************************

* This do files allows the replication of the tables and figures of paper :
* Foreign Expansion, Competition and Bank Risk 
* by Ester Faia, Sebastien Laffitte and Gianmarco Ottaviano
* XX 2019

* It includes tables and figures of the main paper, its appendix and the online appendix
* It uses the external stata packages ppml and xtivreg2
********************************************************************************


 * Set your path
*cd "XXXXXXX/Replication_files"

cd "/Users/sebastienlaffitte/Dropbox/Multinational banks/Clean/Submission/ISOM/Revision 2/Replication files"

		*	Table of contents
		*		I.  REGRESSIONS
		*			1/ Tables 4 to 8
		*			2/ Online Appendix tables 14 and 15
		*			3/ Tables 10 and 11 (appendix main paper)
		*			4/ Online appendix tables 10 and 11
		*		II. DESCRIPTIVE STATISTICS



****************************** I. REGRESSIONS **********************************

* 1/ To obtain the main regressions tables : Tables 4 to 8

		 * a. Run 1.gravity.do to generate the gravity estimates (table 4) and the instruments.
		 do "1.gravity.do"
		 * b. Run 2.dataset_regressions.do to generate the dataset used for the regressions.
		 do "2.dataset_regressions.do"
		 * c. Run 3.baseline_tables.do to obtain tables 5 and 6 and tables 10 and 11 of the online appendix
		 do "3.baseline_tables.do"
		 * d. Run 4.competition_tables.do to obtain tables 7 and 8.
		 do "4.competition_tables.do"
 * NOTE : 1.gravity.do and 2.dataset_regressions.do have to be run necessarilly before running 3.baseline_tables.do or 4.competition_tables.do because these files construct the dataset used for regressions.
 
* 2/ To obtain robstness tables in online appendix 14 and 15 (Dummy for foreign entry instead of count variable) 
		* a. Using the dataset generated above, run 5.dummy_tables.do
		do "5.dummy_tables.do"
		
 
* 3/ To obtain the robustness tables with CvH dataset : Tables 10 to 11

		 * a. Run 1.gravity_cvh.do to generate the gravity estimates and the instruments with CvH data.
		 do "1bis.gravity_cvh.do"
		 * b. Run 2.dataset_regressions.do to generate the dataset used for the regressions.
		 do "2.dataset_regressions.do"
		 * c. Run 5.CvH_tables.do to obtain tables 10 and 11.
		 do "6.CvH_tables.do"
 * NOTE : 1.gravity_cvh.do and 2.dataset_regressions.do have to be run necessarilly before running 5.CvH_tables.do because these files construct the dataset used for regressions.
 
* 4/ To obtain the robustness tables with the alternative-leaning dataset : Tables 10 and 11 of online appendix

		 * a. Run 1.gravity_alt.do to generate the gravity estimates and the instruments with the alternative dataset.
		 do "1ter.gravity_alt.do"
		 * b. Run 2.dataset_regressions.do to generate the dataset used for the regressions.
		 do "2.dataset_regressions.do"
		 * c. Run 7.Alternative_dataset_tables.do to obtain tables 10 and 11 of the online appendix.
		 do "7.Alternative_dataset_tables.do"
		 
 * NOTE : 1.gravity_cvh.do and 2.dataset_regressions.do have to be run necessarilly before running 5.CvH_tables.do because these files construct the dataset used for regressions.


 
************************ II. DESCRIPTIVE STATISTICS ****************************

		 * a. Run 1.gravity.do and 2.dataset_regressions.do to work with the right dataset
		 do "1.gravity.do"
		 do "2.dataset_regressions.do"

		 * b. Run the following codes
		 
* 1/ Table 1: Average risk
table id_bank, c(mean lcds mean llp mean lsd_return_stock_price_ mean lzscore mean lev)
table id_bank, c(mean mean2_lrmes mean mean2_srisk mean delta_covar mean delta_covar_equ)

 
* 2/ Table 2: Description of banks

 * Data on the top 65 banks comes from Bankscope
	 * Table to have the relevant information for 2014
	 table id_bank if year==2014, c(mean tot_assets mean netinc mean llp mean ratio_k)
	 * Table to have the total number of openings
	 table id_bank, c(sum count_bank)
 

* 3/ Table 3: Description of variables
sum count_bank ltot_assets roa_k income_diversity asset_diversity tier1_to_asset deposits_to_asset, sep(10)


* 4/ Figure 1: Map of expansion
 
 * The map is generated using collapsed data that sums openings by host country and origin country
 * The map is done using Khartis software.
 
* 5/ Figure 2: Openings by bank
preserve
collapse (sum) count_bank, by(id_bank)
graph bar (sum) count_bank , over(id_bank, sort(count_bank) des label(angle(45))) ytitle("Sum of entries")
graph export figure2.pdf, replace
restore

* 6/ Figure 3 and 4: Individual and systemic risk
preserve
collapse (mean) lcds llp lsd lzsco mean2_* delta_covar* lev  , by(year)
g mzscore=-lzscore
g lev10=lev/10
twoway  (line lcds year, lcolor(black) yaxis(1)) (line llp year, lcolor(black) lpattern(dash_dot) yaxis(1)) (line lsd_return_stock_price_ year, lcolor(black) lpattern(dash) yaxis(1))  (line mzscore year, lcolor(gs8) yaxis(2)) (line lev10 year, lcolor(black) lpattern("_--_#") yaxis(1)) if year>2004, legend(label(1 "ln(CDS)") label(2 "LLP") label(3 "ln(sd returns)") label(4 "-ln(Z-Score) -- Right axis") label(5 "Leverage Ratio/10")) xlabel(2005(1)2014)
graph export figure3.pdf, replace


twoway  (line mean2_l year, lcolor(black) yaxis(1)) (line mean2_s year, lcolor(black) lpattern(dash_dot) yaxis(1)) (line delta_covar year, lcolor(gs8) lpattern(dash) yaxis(2))  (line delta_covar_equ year, lcolor(gs8) yaxis(2)) if year>2004, legend(label(1 "LRMES") label(2 "SRISK") label(3 "Delta CoVaR -- Right axis") label(4 "Delta CoVaR equ -- Right axis")) xlabel(2005(1)2014) // ylabel(10(10)70) ylabel(0(.1)1.2, axis(2))
graph export figure4.pdf, replace
restore

* 7/ Figure 5: Risk and openings
preserve
bys year : egen min=min(cds)
bys year : egen max=max(cds)
collapse (mean) cds min max (sum) count_bank, by(year)
sort year
label var cds "Avg. CDS Price"
label var min "Min. CDS Price"
label var max "Max. CDS Price"
label var count_bank "Sum of openings"

graph twoway (line cds year, lc(gs10) yaxis(1)) (line min year, lp(dash) lc(gs10) yaxis(1)) (line max year, lp(dash) lc(gs10) yaxis(1)) (line count_bank year, lc(black) lp(solid) yaxis(2)), xlabel(2005(2)2014)
graph export "figure5.pdf", replace
restore

* 8/ Appendix C, Table 9: Risk metrics correlation
corr lcds llp lsd lzsco mean2_* delta_covar* lev







