****************************** REPLICATION FILE ********************************
		*************************************************************
		* This File replicates the gravity equation and the 		*
		* construction of the instruments.							*
		* This corresponds to table 4								*
		*************************************************************



clear all
set matsize 10000
set maxvar  10000


use dataset_FLO, clear

 * Pre-regression settings

	* Fixed effects 4
		egen kj=group(id_bank iso_d)
		egen it=group(iso_o year)
		egen jt=group(iso_d year)
		egen kt=group(id_bank year)
		qui tab jt, g(jt_)
		qui tab kt, g(kt_)
		qui tab id_bank, g(k_)
		qui tab year, g(t_)
		
	* Logs
		foreach var of varlist gdp_o gdp_d distcap tot_assets cds {
			g l`var'=ln(`var')
		}
		

	*Labels
		label var ldistcap "ln(Distance)"
		label var contig  "Contiguity"
		label var comlang_off "Off. Com. Langu."  
		label var eu_ij "Both in the EU"
		label var euro_ij "Both using Euro" 
		label var diff_legalC  "Diff. legal syst."
		
		
		
 ********************* Gravity regression : table 4 ***************************
 

ppml entry  ldistcap contig comlang_off eu_ij euro_ij diff_legalC  kt_* jt_*, cluster (kj)
outreg2 using table4, replace tex nocon drop(kt_* jt_*) label
ppml entry ldistcap contig comlang_off  eu_ij euro_ij diff_legalC , cluster (kj)
outreg2 using table4, append tex nocon  label
* Prediction to construct IV I:
predict p

ppml entry ldistcap contig comlang_off  eu_ij euro_ij diff_legalC  k_* jt_* , cluster(kj)
outreg2 using table4, append tex nocon drop(k_* jt_*) label
* Prediction to construct IV II:
predict p_kjt

 ******************************************************************************

 
 
 
 * Creation of variables used in the next steps : IVs, dependent variable, alternative dependent variable for robustness, variables for competition regressions
	 * Create a dummy for entry in a given market (used in robustness tests, tables 14 and 15 of online appendix)

	g entry_dum=0
	replace entry_dum=1 if entry>0

	bys id_bank year : egen count_bank_dum=total(entry_dum)

	 * Generate the main independant variable and IV.
	 * The IV are named bank_p for IV1 and bank_p_kjt for IV2

		* Instrumental variables
		foreach var of varlist p p_kjt {
		g count_`var'=0
		bys id_bank year : egen bank_`var'=total(`var')  
		}


		* Independant variable : Total number of entries by bank by year 
		bys id_bank year : egen count_bank=total(entry)
		bys id_bank year : egen count_bank_cvh=total(entry_cvh) // Using Claessens and van Horen dataset, for robustness tables 10 and 11 of the paper


 ******************************************************************************



 * We generate two different variables for Openings in higher and lower HHI countries.
 * These variables are used in tables 7 and 8
 
		g hhi_lower=0

		replace hhi_lower=1 if hhi_d < hhi_o
		g hhi_higher=1-hhi_lower

		 * Openings in lower HHI countries
		bys id_bank year : egen count_bank_low_temp=total(entry) if hhi_lower
		bys id_bank year : egen count_bank_low=max(count_bank_low_temp) 
		replace count_bank_low=0 if count_bank_low==.

		 * Openings in higher HHI countries
		bys id_bank year : egen count_bank_high_temp=total(entry) if hhi_higher
		bys id_bank year : egen count_bank_high=max(count_bank_high_temp) 
		replace count_bank_high=0 if count_bank_high==.

		 * Average competition in host countries
		bys id_bank year: egen tm_mpi=mean(mpi_d) if entry>0
		bys id_bank year: egen m_mpi=max(tm_mpi)

		bys id_bank year: egen tm_comov=mean(comov_d) if entry>0
		bys id_bank year: egen m_comov=max(tm_comov)

		 * Hypothesis : we set to the minimum value m_mpi and m_comov when they are missing. This corresponds to banks that do not expand a given year. 
		replace m_mpi=0 if m_mpi==.
		replace m_comov=0 if m_comov==.


 * We generate two different dummy variables for entry in higher and lower HHI countries.
 * It is used in online appendix tables 14 and 15.
		bys id_bank year : egen count_bank_low_dtemp=total(entry_dum) if hhi_lower
		bys id_bank year : egen count_bank_low_dum=max(count_bank_low_dtemp) 
		replace count_bank_low_dum=0 if count_bank_low_dum==.

		bys id_bank year : egen count_bank_high_dtemp=total(entry_dum) if hhi_higher
		bys id_bank year : egen count_bank_high_dum=max(count_bank_high_dtemp) 
		replace count_bank_high_dum=0 if count_bank_high_dum==.


 * We generate two different IV for predicted openings in higher and lower HHI countries.
 * Only IV2 is used in these tables. 
 * IV are named p_kjt_bank_low and p_kjt_bank_high.
 
		foreach var of varlist p_kjt {
		bys id_bank year : egen `var'_bank_low_temp=total(`var') if hhi_lower
		bys id_bank year : egen `var'_bank_low=max(`var'_bank_low_temp) 
		replace `var'_bank_low=0 if `var'_bank_low==.

		bys id_bank year : egen `var'_bank_high_temp=total(`var') if hhi_higher
		bys id_bank year : egen `var'_bank_high=max(`var'_bank_high) 
		replace `var'_bank_high=0 if `var'_bank_high==.
		}
		*	
		
		
 * We generate the predicted dummy for expansion in a market a given year. The threshold for a predicted expansion is set to 0.8.
g p_kjt_dum_t=0
replace p_kjt_dum_t=1 if p_kjt>0.5 

bys id_bank year : egen  bank_p_kjt_dum=total(p_kjt_dum_t)  



				
